# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class AuthNMappingAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "attribute_key": (str,),
            "attribute_value": (str,),
            "created_at": (datetime,),
            "modified_at": (datetime,),
            "saml_assertion_attribute_id": (str,),
        }

    attribute_map = {
        "attribute_key": "attribute_key",
        "attribute_value": "attribute_value",
        "created_at": "created_at",
        "modified_at": "modified_at",
        "saml_assertion_attribute_id": "saml_assertion_attribute_id",
    }
    read_only_vars = {
        "created_at",
        "modified_at",
    }

    def __init__(
        self_,
        attribute_key: Union[str, UnsetType] = unset,
        attribute_value: Union[str, UnsetType] = unset,
        created_at: Union[datetime, UnsetType] = unset,
        modified_at: Union[datetime, UnsetType] = unset,
        saml_assertion_attribute_id: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of AuthN Mapping.

        :param attribute_key: Key portion of a key/value pair of the attribute sent from the Identity Provider.
        :type attribute_key: str, optional

        :param attribute_value: Value portion of a key/value pair of the attribute sent from the Identity Provider.
        :type attribute_value: str, optional

        :param created_at: Creation time of the AuthN Mapping.
        :type created_at: datetime, optional

        :param modified_at: Time of last AuthN Mapping modification.
        :type modified_at: datetime, optional

        :param saml_assertion_attribute_id: The ID of the SAML assertion attribute.
        :type saml_assertion_attribute_id: str, optional
        """
        if attribute_key is not unset:
            kwargs["attribute_key"] = attribute_key
        if attribute_value is not unset:
            kwargs["attribute_value"] = attribute_value
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if saml_assertion_attribute_id is not unset:
            kwargs["saml_assertion_attribute_id"] = saml_assertion_attribute_id
        super().__init__(kwargs)



"""
Submit metrics returns "Payload accepted" response
"""

from datetime import datetime
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType
from datadog_api_client.v2.model.metric_payload import MetricPayload
from datadog_api_client.v2.model.metric_point import MetricPoint
from datadog_api_client.v2.model.metric_resource import MetricResource
from datadog_api_client.v2.model.metric_series import MetricSeries

body = MetricPayload(
    series=[
        MetricSeries(
            metric="system.load.1",
            type=MetricIntakeType.UNSPECIFIED,
            points=[
                MetricPoint(
                    timestamp=int(datetime.now().timestamp()),
                    value=0.7,
                ),
            ],
            resources=[
                MetricResource(
                    name="dummyhost",
                    type="host",
                ),
            ],
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.submit_metrics(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


class LogContent(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "attributes": (
                {
                    str: (
                        bool,
                        date,
                        datetime,
                        dict,
                        float,
                        int,
                        list,
                        str,
                        none_type,
                    )
                },
            ),
            "host": (str,),
            "message": (str,),
            "service": (str,),
            "tags": ([str],),
            "timestamp": (datetime,),
        }

    attribute_map = {
        "attributes": "attributes",
        "host": "host",
        "message": "message",
        "service": "service",
        "tags": "tags",
        "timestamp": "timestamp",
    }

    def __init__(
        self_,
        attributes: Union[Dict[str, Any], UnsetType] = unset,
        host: Union[str, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        service: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        timestamp: Union[datetime, UnsetType] = unset,
        **kwargs,
    ):
        """
        JSON object containing all log attributes and their associated values.

        :param attributes: JSON object of attributes from your log.
        :type attributes: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param host: Name of the machine from where the logs are being sent.
        :type host: str, optional

        :param message: The message `reserved attribute <https://docs.datadoghq.com/logs/log_collection/#reserved-attributes>`_
            of your log. By default, Datadog ingests the value of the message attribute as the body of the log entry.
            That value is then highlighted and displayed in the Logstream, where it is indexed for full text search.
        :type message: str, optional

        :param service: The name of the application or service generating the log events.
            It is used to switch from Logs to APM, so make sure you define the same
            value when you use both products.
        :type service: str, optional

        :param tags: Array of tags associated with your log.
        :type tags: [str], optional

        :param timestamp: Timestamp of your log.
        :type timestamp: datetime, optional
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if host is not unset:
            kwargs["host"] = host
        if message is not unset:
            kwargs["message"] = message
        if service is not unset:
            kwargs["service"] = service
        if tags is not unset:
            kwargs["tags"] = tags
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        super().__init__(kwargs)



"""
Create a new dashboard with distribution widget and apm stats data
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
from datadog_api_client.v1.model.apm_stats_query_row_type import ApmStatsQueryRowType
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
from datadog_api_client.v1.model.distribution_widget_definition_type import DistributionWidgetDefinitionType
from datadog_api_client.v1.model.distribution_widget_request import DistributionWidgetRequest
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_distribution_widget_and_apm_stats_data",
    widgets=[
        Widget(
            definition=DistributionWidgetDefinition(
                title="",
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                type=DistributionWidgetDefinitionType.DISTRIBUTION,
                requests=[
                    DistributionWidgetRequest(
                        apm_stats_query=ApmStatsQueryDefinition(
                            env="prod",
                            service="cassandra",
                            name="cassandra.query",
                            primary_tag="datacenter:dc1",
                            row_type=ApmStatsQueryRowType.SERVICE,
                        ),
                    ),
                ],
            ),
            layout=WidgetLayout(
                x=0,
                y=0,
                width=4,
                height=4,
            ),
        ),
    ],
    layout_type=DashboardLayoutType.ORDERED,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_metadata_type import NotebookMetadataType


class NotebookMetadata(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_metadata_type import NotebookMetadataType

        return {
            "is_template": (bool,),
            "take_snapshots": (bool,),
            "type": (NotebookMetadataType,),
        }

    attribute_map = {
        "is_template": "is_template",
        "take_snapshots": "take_snapshots",
        "type": "type",
    }

    def __init__(
        self_,
        is_template: Union[bool, UnsetType] = unset,
        take_snapshots: Union[bool, UnsetType] = unset,
        type: Union[NotebookMetadataType, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        Metadata associated with the notebook.

        :param is_template: Whether or not the notebook is a template.
        :type is_template: bool, optional

        :param take_snapshots: Whether or not the notebook takes snapshot image backups of the notebook's fixed-time graphs.
        :type take_snapshots: bool, optional

        :param type: Metadata type of the notebook.
        :type type: NotebookMetadataType, none_type, optional
        """
        if is_template is not unset:
            kwargs["is_template"] = is_template
        if take_snapshots is not unset:
            kwargs["take_snapshots"] = take_snapshots
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement_type import (
        SensitiveDataScannerTextReplacementType,
    )


class SensitiveDataScannerTextReplacement(ModelNormal):
    validations = {
        "number_of_chars": {
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement_type import (
            SensitiveDataScannerTextReplacementType,
        )

        return {
            "number_of_chars": (int,),
            "replacement_string": (str,),
            "type": (SensitiveDataScannerTextReplacementType,),
        }

    attribute_map = {
        "number_of_chars": "number_of_chars",
        "replacement_string": "replacement_string",
        "type": "type",
    }

    def __init__(
        self_,
        number_of_chars: Union[int, UnsetType] = unset,
        replacement_string: Union[str, UnsetType] = unset,
        type: Union[SensitiveDataScannerTextReplacementType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing how the scanned event will be replaced.

        :param number_of_chars: Required if type == 'partial_replacement_from_beginning'
            or 'partial_replacement_from_end'. It must be > 0.
        :type number_of_chars: int, optional

        :param replacement_string: Required if type == 'replacement_string'.
        :type replacement_string: str, optional

        :param type: Type of the replacement text. None means no replacement.
            hash means the data will be stubbed. replacement_string means that
            one can chose a text to replace the data. partial_replacement_from_beginning
            allows a user to partially replace the data from the beginning, and
            partial_replacement_from_end on the other hand, allows to replace data from
            the end.
        :type type: SensitiveDataScannerTextReplacementType, optional
        """
        if number_of_chars is not unset:
            kwargs["number_of_chars"] = number_of_chars
        if replacement_string is not unset:
            kwargs["replacement_string"] = replacement_string
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.list_stream_widget_request import ListStreamWidgetRequest
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.list_stream_widget_definition_type import ListStreamWidgetDefinitionType


class ListStreamWidgetDefinition(ModelNormal):
    validations = {
        "requests": {
            "max_items": 1,
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.list_stream_widget_request import ListStreamWidgetRequest
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.list_stream_widget_definition_type import ListStreamWidgetDefinitionType

        return {
            "legend_size": (str,),
            "requests": ([ListStreamWidgetRequest],),
            "show_legend": (bool,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (ListStreamWidgetDefinitionType,),
        }

    attribute_map = {
        "legend_size": "legend_size",
        "requests": "requests",
        "show_legend": "show_legend",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        requests: List[ListStreamWidgetRequest],
        type: ListStreamWidgetDefinitionType,
        legend_size: Union[str, UnsetType] = unset,
        show_legend: Union[bool, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The list stream visualization displays a table of recent events in your application that
        match a search criteria using user-defined columns.

        :param legend_size: Available legend sizes for a widget. Should be one of "0", "2", "4", "8", "16", or "auto".
        :type legend_size: str, optional

        :param requests: Request payload used to query items.
        :type requests: [ListStreamWidgetRequest]

        :param show_legend: Whether or not to display the legend on this widget.
        :type show_legend: bool, optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the list stream widget.
        :type type: ListStreamWidgetDefinitionType
        """
        if legend_size is not unset:
            kwargs["legend_size"] = legend_size
        if show_legend is not unset:
            kwargs["show_legend"] = show_legend
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.requests = requests
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.check_can_delete_slo_response_data import CheckCanDeleteSLOResponseData


class CheckCanDeleteSLOResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.check_can_delete_slo_response_data import CheckCanDeleteSLOResponseData

        return {
            "data": (CheckCanDeleteSLOResponseData,),
            "errors": ({str: (str,)},),
        }

    attribute_map = {
        "data": "data",
        "errors": "errors",
    }

    def __init__(
        self_,
        data: Union[CheckCanDeleteSLOResponseData, UnsetType] = unset,
        errors: Union[Dict[str, str], UnsetType] = unset,
        **kwargs,
    ):
        """
        A service level objective response containing the requested object.

        :param data: An array of service level objective objects.
        :type data: CheckCanDeleteSLOResponseData, optional

        :param errors: A mapping of SLO id to it's current usages.
        :type errors: {str: (str,)}, optional
        """
        if data is not unset:
            kwargs["data"] = data
        if errors is not unset:
            kwargs["errors"] = errors
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole


class AuthNMappingCreateRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole

        return {
            "role": (RelationshipToRole,),
        }

    attribute_map = {
        "role": "role",
    }

    def __init__(self_, role: Union[RelationshipToRole, UnsetType] = unset, **kwargs):
        """
        Relationship of AuthN Mapping create object to Role.

        :param role: Relationship to role.
        :type role: RelationshipToRole, optional
        """
        if role is not unset:
            kwargs["role"] = role
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.relationship_to_permissions import RelationshipToPermissions


class RoleResponseRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.relationship_to_permissions import RelationshipToPermissions

        return {
            "permissions": (RelationshipToPermissions,),
        }

    attribute_map = {
        "permissions": "permissions",
    }

    def __init__(self_, permissions: Union[RelationshipToPermissions, UnsetType] = unset, **kwargs):
        """
        Relationships of the role object returned by the API.

        :param permissions: Relationship to multiple permissions objects.
        :type permissions: RelationshipToPermissions, optional
        """
        if permissions is not unset:
            kwargs["permissions"] = permissions
        super().__init__(kwargs)



"""
Delete a security filter returns "No Content" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

# there is a valid "security_filter" in the system
SECURITY_FILTER_DATA_ID = environ["SECURITY_FILTER_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    api_instance.delete_security_filter(
        security_filter_id=SECURITY_FILTER_DATA_ID,
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_string_builder_processor_type import LogsStringBuilderProcessorType


class LogsStringBuilderProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_string_builder_processor_type import LogsStringBuilderProcessorType

        return {
            "is_enabled": (bool,),
            "is_replace_missing": (bool,),
            "name": (str,),
            "target": (str,),
            "template": (str,),
            "type": (LogsStringBuilderProcessorType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "is_replace_missing": "is_replace_missing",
        "name": "name",
        "target": "target",
        "template": "template",
        "type": "type",
    }

    def __init__(
        self_,
        target: str,
        template: str,
        type: LogsStringBuilderProcessorType,
        is_enabled: Union[bool, UnsetType] = unset,
        is_replace_missing: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Use the string builder processor to add a new attribute (without spaces or special characters)
        to a log with the result of the provided template.
        This enables aggregation of different attributes or raw strings into a single attribute.

        The template is defined by both raw text and blocks with the syntax ``%{attribute_path}``.

        **Notes** :

        * The processor only accepts attributes with values or an array of values in the blocks.
        * If an attribute cannot be used (object or array of object),
          it is replaced by an empty string or the entire operation is skipped depending on your selection.
        * If the target attribute already exists, it is overwritten by the result of the template.
        * Results of the template cannot exceed 256 characters.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param is_replace_missing: If true, it replaces all missing attributes of ``template`` by an empty string.
            If ``false`` (default), skips the operation for missing attributes.
        :type is_replace_missing: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param target: The name of the attribute that contains the result of the template.
        :type target: str

        :param template: A formula with one or more attributes and raw text.
        :type template: str

        :param type: Type of logs string builder processor.
        :type type: LogsStringBuilderProcessorType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if is_replace_missing is not unset:
            kwargs["is_replace_missing"] = is_replace_missing
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.target = target
        self_.template = template
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_grouping import WidgetGrouping
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.check_status_widget_definition_type import CheckStatusWidgetDefinitionType


class CheckStatusWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_grouping import WidgetGrouping
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.check_status_widget_definition_type import CheckStatusWidgetDefinitionType

        return {
            "check": (str,),
            "group": (str,),
            "group_by": ([str],),
            "grouping": (WidgetGrouping,),
            "tags": ([str],),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (CheckStatusWidgetDefinitionType,),
        }

    attribute_map = {
        "check": "check",
        "group": "group",
        "group_by": "group_by",
        "grouping": "grouping",
        "tags": "tags",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        check: str,
        grouping: WidgetGrouping,
        type: CheckStatusWidgetDefinitionType,
        group: Union[str, UnsetType] = unset,
        group_by: Union[List[str], UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Check status shows the current status or number of results for any check performed.

        :param check: Name of the check to use in the widget.
        :type check: str

        :param group: Group reporting a single check.
        :type group: str, optional

        :param group_by: List of tag prefixes to group by in the case of a cluster check.
        :type group_by: [str], optional

        :param grouping: The kind of grouping to use.
        :type grouping: WidgetGrouping

        :param tags: List of tags used to filter the groups reporting a cluster check.
        :type tags: [str], optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the check status widget.
        :type type: CheckStatusWidgetDefinitionType
        """
        if group is not unset:
            kwargs["group"] = group
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if tags is not unset:
            kwargs["tags"] = tags
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.check = check
        self_.grouping = grouping
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class SyntheticsDeletedTest(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "deleted_at": (datetime,),
            "public_id": (str,),
        }

    attribute_map = {
        "deleted_at": "deleted_at",
        "public_id": "public_id",
    }

    def __init__(
        self_, deleted_at: Union[datetime, UnsetType] = unset, public_id: Union[str, UnsetType] = unset, **kwargs
    ):
        """
        Object containing a deleted Synthetic test ID with the associated
        deletion timestamp.

        :param deleted_at: Deletion timestamp of the Synthetic test ID.
        :type deleted_at: datetime, optional

        :param public_id: The Synthetic test ID deleted.
        :type public_id: str, optional
        """
        if deleted_at is not unset:
            kwargs["deleted_at"] = deleted_at
        if public_id is not unset:
            kwargs["public_id"] = public_id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class LogsAPIError(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "code": (str,),
            "details": ([LogsAPIError],),
            "message": (str,),
        }

    attribute_map = {
        "code": "code",
        "details": "details",
        "message": "message",
    }

    def __init__(
        self_,
        code: Union[str, UnsetType] = unset,
        details: Union[List[LogsAPIError], UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Error returned by the Logs API

        :param code: Code identifying the error
        :type code: str, optional

        :param details: Additional error details
        :type details: [LogsAPIError], optional

        :param message: Error message
        :type message: str, optional
        """
        if code is not unset:
            kwargs["code"] = code
        if details is not unset:
            kwargs["details"] = details
        if message is not unset:
            kwargs["message"] = message
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.target_format_type import TargetFormatType
    from datadog_api_client.v1.model.logs_attribute_remapper_type import LogsAttributeRemapperType


class LogsAttributeRemapper(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.target_format_type import TargetFormatType
        from datadog_api_client.v1.model.logs_attribute_remapper_type import LogsAttributeRemapperType

        return {
            "is_enabled": (bool,),
            "name": (str,),
            "override_on_conflict": (bool,),
            "preserve_source": (bool,),
            "source_type": (str,),
            "sources": ([str],),
            "target": (str,),
            "target_format": (TargetFormatType,),
            "target_type": (str,),
            "type": (LogsAttributeRemapperType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "name": "name",
        "override_on_conflict": "override_on_conflict",
        "preserve_source": "preserve_source",
        "source_type": "source_type",
        "sources": "sources",
        "target": "target",
        "target_format": "target_format",
        "target_type": "target_type",
        "type": "type",
    }

    def __init__(
        self_,
        sources: List[str],
        target: str,
        type: LogsAttributeRemapperType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        override_on_conflict: Union[bool, UnsetType] = unset,
        preserve_source: Union[bool, UnsetType] = unset,
        source_type: Union[str, UnsetType] = unset,
        target_format: Union[TargetFormatType, UnsetType] = unset,
        target_type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The remapper processor remaps any source attribute(s) or tag to another target attribute or tag.
        Constraints on the tag/attribute name are explained in the `Tag Best Practice documentation <https://docs.datadoghq.com/logs/guide/log-parsing-best-practice>`_.
        Some additional constraints are applied as ``:`` or ``,`` are not allowed in the target tag/attribute name.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param override_on_conflict: Override or not the target element if already set,
        :type override_on_conflict: bool, optional

        :param preserve_source: Remove or preserve the remapped source element.
        :type preserve_source: bool, optional

        :param source_type: Defines if the sources are from log ``attribute`` or ``tag``.
        :type source_type: str, optional

        :param sources: Array of source attributes.
        :type sources: [str]

        :param target: Final attribute or tag name to remap the sources to.
        :type target: str

        :param target_format: If the ``target_type`` of the remapper is ``attribute`` , try to cast the value to a new specific type.
            If the cast is not possible, the original type is kept. ``string`` , ``integer`` , or ``double`` are the possible types.
            If the ``target_type`` is ``tag`` , this parameter may not be specified.
        :type target_format: TargetFormatType, optional

        :param target_type: Defines if the final attribute or tag name is from log ``attribute`` or ``tag``.
        :type target_type: str, optional

        :param type: Type of logs attribute remapper.
        :type type: LogsAttributeRemapperType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if override_on_conflict is not unset:
            kwargs["override_on_conflict"] = override_on_conflict
        if preserve_source is not unset:
            kwargs["preserve_source"] = preserve_source
        if source_type is not unset:
            kwargs["source_type"] = source_type
        if target_format is not unset:
            kwargs["target_format"] = target_format
        if target_type is not unset:
            kwargs["target_type"] = target_type
        super().__init__(kwargs)

        self_.sources = sources
        self_.target = target
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_options_scheduling_options_evaluation_window import (
        MonitorOptionsSchedulingOptionsEvaluationWindow,
    )


class MonitorOptionsSchedulingOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_options_scheduling_options_evaluation_window import (
            MonitorOptionsSchedulingOptionsEvaluationWindow,
        )

        return {
            "evaluation_window": (MonitorOptionsSchedulingOptionsEvaluationWindow,),
        }

    attribute_map = {
        "evaluation_window": "evaluation_window",
    }

    def __init__(
        self_, evaluation_window: Union[MonitorOptionsSchedulingOptionsEvaluationWindow, UnsetType] = unset, **kwargs
    ):
        """
        Configuration options for scheduling.

        :param evaluation_window: Configuration options for the evaluation window. If ``hour_starts`` is set, no other fields may be set. Otherwise, ``day_starts`` and ``month_starts`` must be set together.
        :type evaluation_window: MonitorOptionsSchedulingOptionsEvaluationWindow, optional
        """
        if evaluation_window is not unset:
            kwargs["evaluation_window"] = evaluation_window
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UserCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "email": (str,),
            "name": (str,),
            "title": (str,),
        }

    attribute_map = {
        "email": "email",
        "name": "name",
        "title": "title",
    }

    def __init__(
        self_, email: str, name: Union[str, UnsetType] = unset, title: Union[str, UnsetType] = unset, **kwargs
    ):
        """
        Attributes of the created user.

        :param email: The email of the user.
        :type email: str

        :param name: The name of the user.
        :type name: str, optional

        :param title: The title of the user.
        :type title: str, optional
        """
        if name is not unset:
            kwargs["name"] = name
        if title is not unset:
            kwargs["title"] = title
        super().__init__(kwargs)

        self_.email = email



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_bulk_tag_config_status_attributes import MetricBulkTagConfigStatusAttributes
    from datadog_api_client.v2.model.metric_bulk_configure_tags_type import MetricBulkConfigureTagsType


class MetricBulkTagConfigStatus(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_bulk_tag_config_status_attributes import (
            MetricBulkTagConfigStatusAttributes,
        )
        from datadog_api_client.v2.model.metric_bulk_configure_tags_type import MetricBulkConfigureTagsType

        return {
            "attributes": (MetricBulkTagConfigStatusAttributes,),
            "id": (str,),
            "type": (MetricBulkConfigureTagsType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "type": "type",
    }

    def __init__(
        self_,
        id: str,
        type: MetricBulkConfigureTagsType,
        attributes: Union[MetricBulkTagConfigStatusAttributes, UnsetType] = unset,
        **kwargs,
    ):
        """
        The status of a request to bulk configure metric tags.
        It contains the fields from the original request for reference.

        :param attributes: Optional attributes for the status of a bulk tag configuration request.
        :type attributes: MetricBulkTagConfigStatusAttributes, optional

        :param id: A text prefix to match against metric names.
        :type id: str

        :param type: The metric bulk configure tags resource.
        :type type: MetricBulkConfigureTagsType
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        super().__init__(kwargs)

        self_.id = id
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_filter import LogsFilter
    from datadog_api_client.v1.model.logs_processor import LogsProcessor
    from datadog_api_client.v1.model.logs_pipeline_processor_type import LogsPipelineProcessorType
    from datadog_api_client.v1.model.logs_grok_parser import LogsGrokParser
    from datadog_api_client.v1.model.logs_date_remapper import LogsDateRemapper
    from datadog_api_client.v1.model.logs_status_remapper import LogsStatusRemapper
    from datadog_api_client.v1.model.logs_service_remapper import LogsServiceRemapper
    from datadog_api_client.v1.model.logs_message_remapper import LogsMessageRemapper
    from datadog_api_client.v1.model.logs_attribute_remapper import LogsAttributeRemapper
    from datadog_api_client.v1.model.logs_url_parser import LogsURLParser
    from datadog_api_client.v1.model.logs_user_agent_parser import LogsUserAgentParser
    from datadog_api_client.v1.model.logs_category_processor import LogsCategoryProcessor
    from datadog_api_client.v1.model.logs_arithmetic_processor import LogsArithmeticProcessor
    from datadog_api_client.v1.model.logs_string_builder_processor import LogsStringBuilderProcessor
    from datadog_api_client.v1.model.logs_geo_ip_parser import LogsGeoIPParser
    from datadog_api_client.v1.model.logs_lookup_processor import LogsLookupProcessor
    from datadog_api_client.v1.model.reference_table_logs_lookup_processor import ReferenceTableLogsLookupProcessor
    from datadog_api_client.v1.model.logs_trace_remapper import LogsTraceRemapper


class LogsPipelineProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_filter import LogsFilter
        from datadog_api_client.v1.model.logs_processor import LogsProcessor
        from datadog_api_client.v1.model.logs_pipeline_processor_type import LogsPipelineProcessorType

        return {
            "filter": (LogsFilter,),
            "is_enabled": (bool,),
            "name": (str,),
            "processors": ([LogsProcessor],),
            "type": (LogsPipelineProcessorType,),
        }

    attribute_map = {
        "filter": "filter",
        "is_enabled": "is_enabled",
        "name": "name",
        "processors": "processors",
        "type": "type",
    }

    def __init__(
        self_,
        type: LogsPipelineProcessorType,
        filter: Union[LogsFilter, UnsetType] = unset,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        processors: Union[
            List[
                Union[
                    LogsProcessor,
                    LogsGrokParser,
                    LogsDateRemapper,
                    LogsStatusRemapper,
                    LogsServiceRemapper,
                    LogsMessageRemapper,
                    LogsAttributeRemapper,
                    LogsURLParser,
                    LogsUserAgentParser,
                    LogsCategoryProcessor,
                    LogsArithmeticProcessor,
                    LogsStringBuilderProcessor,
                    LogsPipelineProcessor,
                    LogsGeoIPParser,
                    LogsLookupProcessor,
                    ReferenceTableLogsLookupProcessor,
                    LogsTraceRemapper,
                ]
            ],
            UnsetType,
        ] = unset,
        **kwargs,
    ):
        """
        Nested Pipelines are pipelines within a pipeline. Use Nested Pipelines to split the processing into two steps.
        For example, first use a high-level filtering such as team and then a second level of filtering based on the
        integration, service, or any other tag or attribute.

        A pipeline can contain Nested Pipelines and Processors whereas a Nested Pipeline can only contain Processors.

        :param filter: Filter for logs.
        :type filter: LogsFilter, optional

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param processors: Ordered list of processors in this pipeline.
        :type processors: [LogsProcessor], optional

        :param type: Type of logs pipeline processor.
        :type type: LogsPipelineProcessorType
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if processors is not unset:
            kwargs["processors"] = processors
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser
    from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
        SyntheticsGlobalVariableParseTestOptionsType,
    )


class SyntheticsGlobalVariableParseTestOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser
        from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
            SyntheticsGlobalVariableParseTestOptionsType,
        )

        return {
            "field": (str,),
            "local_variable_name": (str,),
            "parser": (SyntheticsVariableParser,),
            "type": (SyntheticsGlobalVariableParseTestOptionsType,),
        }

    attribute_map = {
        "field": "field",
        "local_variable_name": "localVariableName",
        "parser": "parser",
        "type": "type",
    }

    def __init__(
        self_,
        type: SyntheticsGlobalVariableParseTestOptionsType,
        field: Union[str, UnsetType] = unset,
        local_variable_name: Union[str, UnsetType] = unset,
        parser: Union[SyntheticsVariableParser, UnsetType] = unset,
        **kwargs,
    ):
        """
        Parser options to use for retrieving a Synthetics global variable from a Synthetics Test. Used in conjunction with ``parse_test_public_id``.

        :param field: When type is ``http_header`` , name of the header to use to extract the value.
        :type field: str, optional

        :param local_variable_name: When type is ``local_variable`` , name of the local variable to use to extract the value.
        :type local_variable_name: str, optional

        :param parser: Details of the parser to use for the global variable.
        :type parser: SyntheticsVariableParser, optional

        :param type: Property of the Synthetics Test Response to use for a Synthetics global variable.
        :type type: SyntheticsGlobalVariableParseTestOptionsType
        """
        if field is not unset:
            kwargs["field"] = field
        if local_variable_name is not unset:
            kwargs["local_variable_name"] = local_variable_name
        if parser is not unset:
            kwargs["parser"] = parser
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleSeverity(ModelSimple):
    """
    Severity of the Security Signal.

    :param value: Must be one of ["info", "low", "medium", "high", "critical"].
    :type value: str
    """

    allowed_values = {
        "info",
        "low",
        "medium",
        "high",
        "critical",
    }
    INFO: ClassVar["SecurityMonitoringRuleSeverity"]
    LOW: ClassVar["SecurityMonitoringRuleSeverity"]
    MEDIUM: ClassVar["SecurityMonitoringRuleSeverity"]
    HIGH: ClassVar["SecurityMonitoringRuleSeverity"]
    CRITICAL: ClassVar["SecurityMonitoringRuleSeverity"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringRuleSeverity.INFO = SecurityMonitoringRuleSeverity("info")
SecurityMonitoringRuleSeverity.LOW = SecurityMonitoringRuleSeverity("low")
SecurityMonitoringRuleSeverity.MEDIUM = SecurityMonitoringRuleSeverity("medium")
SecurityMonitoringRuleSeverity.HIGH = SecurityMonitoringRuleSeverity("high")
SecurityMonitoringRuleSeverity.CRITICAL = SecurityMonitoringRuleSeverity("critical")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
    from datadog_api_client.v1.model.widget_node_type import WidgetNodeType
    from datadog_api_client.v1.model.host_map_widget_definition_requests import HostMapWidgetDefinitionRequests
    from datadog_api_client.v1.model.host_map_widget_definition_style import HostMapWidgetDefinitionStyle
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.host_map_widget_definition_type import HostMapWidgetDefinitionType


class HostMapWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
        from datadog_api_client.v1.model.widget_node_type import WidgetNodeType
        from datadog_api_client.v1.model.host_map_widget_definition_requests import HostMapWidgetDefinitionRequests
        from datadog_api_client.v1.model.host_map_widget_definition_style import HostMapWidgetDefinitionStyle
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.host_map_widget_definition_type import HostMapWidgetDefinitionType

        return {
            "custom_links": ([WidgetCustomLink],),
            "group": ([str],),
            "no_group_hosts": (bool,),
            "no_metric_hosts": (bool,),
            "node_type": (WidgetNodeType,),
            "notes": (str,),
            "requests": (HostMapWidgetDefinitionRequests,),
            "scope": ([str],),
            "style": (HostMapWidgetDefinitionStyle,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (HostMapWidgetDefinitionType,),
        }

    attribute_map = {
        "custom_links": "custom_links",
        "group": "group",
        "no_group_hosts": "no_group_hosts",
        "no_metric_hosts": "no_metric_hosts",
        "node_type": "node_type",
        "notes": "notes",
        "requests": "requests",
        "scope": "scope",
        "style": "style",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        requests: HostMapWidgetDefinitionRequests,
        type: HostMapWidgetDefinitionType,
        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
        group: Union[List[str], UnsetType] = unset,
        no_group_hosts: Union[bool, UnsetType] = unset,
        no_metric_hosts: Union[bool, UnsetType] = unset,
        node_type: Union[WidgetNodeType, UnsetType] = unset,
        notes: Union[str, UnsetType] = unset,
        scope: Union[List[str], UnsetType] = unset,
        style: Union[HostMapWidgetDefinitionStyle, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The host map widget graphs any metric across your hosts using the same visualization available from the main Host Map page.

        :param custom_links: List of custom links.
        :type custom_links: [WidgetCustomLink], optional

        :param group: List of tag prefixes to group by.
        :type group: [str], optional

        :param no_group_hosts: Whether to show the hosts that don’t fit in a group.
        :type no_group_hosts: bool, optional

        :param no_metric_hosts: Whether to show the hosts with no metrics.
        :type no_metric_hosts: bool, optional

        :param node_type: Which type of node to use in the map.
        :type node_type: WidgetNodeType, optional

        :param notes: Notes on the title.
        :type notes: str, optional

        :param requests: List of definitions.
        :type requests: HostMapWidgetDefinitionRequests

        :param scope: List of tags used to filter the map.
        :type scope: [str], optional

        :param style: The style to apply to the widget.
        :type style: HostMapWidgetDefinitionStyle, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the host map widget.
        :type type: HostMapWidgetDefinitionType
        """
        if custom_links is not unset:
            kwargs["custom_links"] = custom_links
        if group is not unset:
            kwargs["group"] = group
        if no_group_hosts is not unset:
            kwargs["no_group_hosts"] = no_group_hosts
        if no_metric_hosts is not unset:
            kwargs["no_metric_hosts"] = no_metric_hosts
        if node_type is not unset:
            kwargs["node_type"] = node_type
        if notes is not unset:
            kwargs["notes"] = notes
        if scope is not unset:
            kwargs["scope"] = scope
        if style is not unset:
            kwargs["style"] = style
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.requests = requests
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
    from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
    from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
    from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType


class TreeMapWidgetDefinition(ModelNormal):
    validations = {
        "requests": {
            "max_items": 1,
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
        from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
        from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
        from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType

        return {
            "color_by": (TreeMapColorBy,),
            "custom_links": ([WidgetCustomLink],),
            "group_by": (TreeMapGroupBy,),
            "requests": ([TreeMapWidgetRequest],),
            "size_by": (TreeMapSizeBy,),
            "time": (WidgetTime,),
            "title": (str,),
            "type": (TreeMapWidgetDefinitionType,),
        }

    attribute_map = {
        "color_by": "color_by",
        "custom_links": "custom_links",
        "group_by": "group_by",
        "requests": "requests",
        "size_by": "size_by",
        "time": "time",
        "title": "title",
        "type": "type",
    }

    def __init__(
        self_,
        requests: List[TreeMapWidgetRequest],
        type: TreeMapWidgetDefinitionType,
        color_by: Union[TreeMapColorBy, UnsetType] = unset,
        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
        group_by: Union[TreeMapGroupBy, UnsetType] = unset,
        size_by: Union[TreeMapSizeBy, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The treemap visualization enables you to display hierarchical and nested data. It is well suited for queries that describe part-whole relationships, such as resource usage by availability zone, data center, or team.

        :param color_by: (deprecated) The attribute formerly used to determine color in the widget. **Deprecated**.
        :type color_by: TreeMapColorBy, optional

        :param custom_links: List of custom links.
        :type custom_links: [WidgetCustomLink], optional

        :param group_by: (deprecated) The attribute formerly used to group elements in the widget. **Deprecated**.
        :type group_by: TreeMapGroupBy, optional

        :param requests: List of treemap widget requests.
        :type requests: [TreeMapWidgetRequest]

        :param size_by: (deprecated) The attribute formerly used to determine size in the widget. **Deprecated**.
        :type size_by: TreeMapSizeBy, optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of your widget.
        :type title: str, optional

        :param type: Type of the treemap widget.
        :type type: TreeMapWidgetDefinitionType
        """
        if color_by is not unset:
            kwargs["color_by"] = color_by
        if custom_links is not unset:
            kwargs["custom_links"] = custom_links
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if size_by is not unset:
            kwargs["size_by"] = size_by
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        super().__init__(kwargs)

        self_.requests = requests
        self_.type = type



"""
Create a distribution widget using a histogram request containing a formulas and functions APM Stats query
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
from datadog_api_client.v1.model.distribution_widget_definition_type import DistributionWidgetDefinitionType
from datadog_api_client.v1.model.distribution_widget_histogram_request_type import (
    DistributionWidgetHistogramRequestType,
)
from datadog_api_client.v1.model.distribution_widget_request import DistributionWidgetRequest
from datadog_api_client.v1.model.distribution_widget_x_axis import DistributionWidgetXAxis
from datadog_api_client.v1.model.distribution_widget_y_axis import DistributionWidgetYAxis
from datadog_api_client.v1.model.formula_and_function_apm_resource_stat_name import (
    FormulaAndFunctionApmResourceStatName,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_data_source import (
    FormulaAndFunctionApmResourceStatsDataSource,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_query_definition import (
    FormulaAndFunctionApmResourceStatsQueryDefinition,
)
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_style import WidgetStyle
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

body = Dashboard(
    title="Example-Create_a_distribution_widget_using_a_histogram_request_containing_a_formulas_and_functions_APM_Stats",
    description="",
    widgets=[
        Widget(
            definition=DistributionWidgetDefinition(
                title="APM Stats - Request latency HOP",
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                show_legend=False,
                type=DistributionWidgetDefinitionType.DISTRIBUTION,
                xaxis=DistributionWidgetXAxis(
                    max="auto",
                    include_zero=True,
                    scale="linear",
                    min="auto",
                ),
                yaxis=DistributionWidgetYAxis(
                    max="auto",
                    include_zero=True,
                    scale="linear",
                    min="auto",
                ),
                requests=[
                    DistributionWidgetRequest(
                        query=FormulaAndFunctionApmResourceStatsQueryDefinition(
                            primary_tag_value="*",
                            stat=FormulaAndFunctionApmResourceStatName.LATENCY_DISTRIBUTION,
                            data_source=FormulaAndFunctionApmResourceStatsDataSource.APM_RESOURCE_STATS,
                            name="query1",
                            service="azure-bill-import",
                            group_by=[
                                "resource_name",
                            ],
                            env="staging",
                            primary_tag_name="datacenter",
                            operation_name="universal.http.client",
                        ),
                        request_type=DistributionWidgetHistogramRequestType.HISTOGRAM,
                        style=WidgetStyle(
                            palette="dog_classic",
                        ),
                    ),
                ],
            ),
            layout=WidgetLayout(
                x=8,
                y=0,
                width=4,
                height=2,
            ),
        ),
    ],
    layout_type=DashboardLayoutType.ORDERED,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class WebhooksIntegrationCustomVariable(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "is_secret": (bool,),
            "name": (str,),
            "value": (str,),
        }

    attribute_map = {
        "is_secret": "is_secret",
        "name": "name",
        "value": "value",
    }

    def __init__(self_, is_secret: bool, name: str, value: str, **kwargs):
        """
        Custom variable for Webhook integration.

        :param is_secret: Make custom variable is secret or not.
            If the custom variable is secret, the value is not returned in the response payload.
        :type is_secret: bool

        :param name: The name of the variable. It corresponds with ``<CUSTOM_VARIABLE_NAME>``.
        :type name: str

        :param value: Value of the custom variable.
        :type value: str
        """
        super().__init__(kwargs)

        self_.is_secret = is_secret
        self_.name = name
        self_.value = value



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.

from datadog_api_client.api_client import ApiClient, AsyncApiClient
from datadog_api_client.configuration import Configuration
from datadog_api_client.exceptions import (
    OpenApiException,
    ApiAttributeError,
    ApiTypeError,
    ApiValueError,
    ApiKeyError,
    ApiException,
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v2.model.opsgenie_services_response import OpsgenieServicesResponse
from datadog_api_client.v2.model.opsgenie_service_response import OpsgenieServiceResponse
from datadog_api_client.v2.model.opsgenie_service_create_request import OpsgenieServiceCreateRequest
from datadog_api_client.v2.model.opsgenie_service_update_request import OpsgenieServiceUpdateRequest


class OpsgenieIntegrationApi:
    """
    Configure your `Datadog Opsgenie integration <https://docs.datadoghq.com/integrations/opsgenie/>`_
    directly through the Datadog API.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_opsgenie_service_endpoint = _Endpoint(
            settings={
                "response_type": (OpsgenieServiceResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/integration/opsgenie/services",
                "operation_id": "create_opsgenie_service",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (OpsgenieServiceCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_opsgenie_service_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/integration/opsgenie/services/{integration_service_id}",
                "operation_id": "delete_opsgenie_service",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "integration_service_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "integration_service_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_opsgenie_service_endpoint = _Endpoint(
            settings={
                "response_type": (OpsgenieServiceResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/integration/opsgenie/services/{integration_service_id}",
                "operation_id": "get_opsgenie_service",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "integration_service_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "integration_service_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_opsgenie_services_endpoint = _Endpoint(
            settings={
                "response_type": (OpsgenieServicesResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/integration/opsgenie/services",
                "operation_id": "list_opsgenie_services",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_opsgenie_service_endpoint = _Endpoint(
            settings={
                "response_type": (OpsgenieServiceResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/integration/opsgenie/services/{integration_service_id}",
                "operation_id": "update_opsgenie_service",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "integration_service_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "integration_service_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (OpsgenieServiceUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_opsgenie_service(
        self,
        body: OpsgenieServiceCreateRequest,
    ) -> OpsgenieServiceResponse:
        """Create a new service object.

        Create a new service object in the Opsgenie integration.

        :param body: Opsgenie service payload
        :type body: OpsgenieServiceCreateRequest
        :rtype: OpsgenieServiceResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_opsgenie_service_endpoint.call_with_http_info(**kwargs)

    def delete_opsgenie_service(
        self,
        integration_service_id: str,
    ) -> None:
        """Delete a single service object.

        Delete a single service object in the Datadog Opsgenie integration.

        :param integration_service_id: The UUID of the service.
        :type integration_service_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["integration_service_id"] = integration_service_id

        return self._delete_opsgenie_service_endpoint.call_with_http_info(**kwargs)

    def get_opsgenie_service(
        self,
        integration_service_id: str,
    ) -> OpsgenieServiceResponse:
        """Get a single service object.

        Get a single service from the Datadog Opsgenie integration.

        :param integration_service_id: The UUID of the service.
        :type integration_service_id: str
        :rtype: OpsgenieServiceResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["integration_service_id"] = integration_service_id

        return self._get_opsgenie_service_endpoint.call_with_http_info(**kwargs)

    def list_opsgenie_services(
        self,
    ) -> OpsgenieServicesResponse:
        """Get all service objects.

        Get a list of all services from the Datadog Opsgenie integration.

        :rtype: OpsgenieServicesResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_opsgenie_services_endpoint.call_with_http_info(**kwargs)

    def update_opsgenie_service(
        self,
        integration_service_id: str,
        body: OpsgenieServiceUpdateRequest,
    ) -> OpsgenieServiceResponse:
        """Update a single service object.

        Update a single service object in the Datadog Opsgenie integration.

        :param integration_service_id: The UUID of the service.
        :type integration_service_id: str
        :param body: Opsgenie service payload.
        :type body: OpsgenieServiceUpdateRequest
        :rtype: OpsgenieServiceResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["integration_service_id"] = integration_service_id

        kwargs["body"] = body

        return self._update_opsgenie_service_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates


class MonitorGroupSearchResult(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates

        return {
            "group": (str,),
            "group_tags": ([str],),
            "last_nodata_ts": (int,),
            "last_triggered_ts": (int, none_type),
            "monitor_id": (int,),
            "monitor_name": (str,),
            "status": (MonitorOverallStates,),
        }

    attribute_map = {
        "group": "group",
        "group_tags": "group_tags",
        "last_nodata_ts": "last_nodata_ts",
        "last_triggered_ts": "last_triggered_ts",
        "monitor_id": "monitor_id",
        "monitor_name": "monitor_name",
        "status": "status",
    }
    read_only_vars = {
        "group",
        "group_tags",
        "last_nodata_ts",
        "last_triggered_ts",
        "monitor_id",
        "monitor_name",
        "status",
    }

    def __init__(
        self_,
        group: Union[str, UnsetType] = unset,
        group_tags: Union[List[str], UnsetType] = unset,
        last_nodata_ts: Union[int, UnsetType] = unset,
        last_triggered_ts: Union[int, none_type, UnsetType] = unset,
        monitor_id: Union[int, UnsetType] = unset,
        monitor_name: Union[str, UnsetType] = unset,
        status: Union[MonitorOverallStates, UnsetType] = unset,
        **kwargs,
    ):
        """
        A single monitor group search result.

        :param group: The name of the group.
        :type group: str, optional

        :param group_tags: The list of tags of the monitor group.
        :type group_tags: [str], optional

        :param last_nodata_ts: Latest timestamp the monitor group was in NO_DATA state.
        :type last_nodata_ts: int, optional

        :param last_triggered_ts: Latest timestamp the monitor group triggered.
        :type last_triggered_ts: int, none_type, optional

        :param monitor_id: The ID of the monitor.
        :type monitor_id: int, optional

        :param monitor_name: The name of the monitor.
        :type monitor_name: str, optional

        :param status: The different states your monitor can be in.
        :type status: MonitorOverallStates, optional
        """
        if group is not unset:
            kwargs["group"] = group
        if group_tags is not unset:
            kwargs["group_tags"] = group_tags
        if last_nodata_ts is not unset:
            kwargs["last_nodata_ts"] = last_nodata_ts
        if last_triggered_ts is not unset:
            kwargs["last_triggered_ts"] = last_triggered_ts
        if monitor_id is not unset:
            kwargs["monitor_id"] = monitor_id
        if monitor_name is not unset:
            kwargs["monitor_name"] = monitor_name
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.relationship_to_user import RelationshipToUser


class ApplicationKeyRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.relationship_to_user import RelationshipToUser

        return {
            "owned_by": (RelationshipToUser,),
        }

    attribute_map = {
        "owned_by": "owned_by",
    }

    def __init__(self_, owned_by: Union[RelationshipToUser, UnsetType] = unset, **kwargs):
        """
        Resources related to the application key.

        :param owned_by: Relationship to user.
        :type owned_by: RelationshipToUser, optional
        """
        if owned_by is not unset:
            kwargs["owned_by"] = owned_by
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence


class DowntimeChild(ModelNormal):
    validations = {
        "creator_id": {
            "inclusive_maximum": 2147483647,
        },
        "downtime_type": {
            "inclusive_maximum": 2147483647,
        },
        "updater_id": {
            "inclusive_maximum": 2147483647,
        },
    }
    _nullable = True

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence

        return {
            "active": (bool,),
            "canceled": (int, none_type),
            "creator_id": (int,),
            "disabled": (bool,),
            "downtime_type": (int,),
            "end": (int, none_type),
            "id": (int,),
            "message": (str,),
            "monitor_id": (int, none_type),
            "monitor_tags": ([str],),
            "mute_first_recovery_notification": (bool,),
            "parent_id": (int, none_type),
            "recurrence": (DowntimeRecurrence,),
            "scope": ([str],),
            "start": (int,),
            "timezone": (str,),
            "updater_id": (int, none_type),
        }

    attribute_map = {
        "active": "active",
        "canceled": "canceled",
        "creator_id": "creator_id",
        "disabled": "disabled",
        "downtime_type": "downtime_type",
        "end": "end",
        "id": "id",
        "message": "message",
        "monitor_id": "monitor_id",
        "monitor_tags": "monitor_tags",
        "mute_first_recovery_notification": "mute_first_recovery_notification",
        "parent_id": "parent_id",
        "recurrence": "recurrence",
        "scope": "scope",
        "start": "start",
        "timezone": "timezone",
        "updater_id": "updater_id",
    }
    read_only_vars = {
        "active",
        "canceled",
        "creator_id",
        "downtime_type",
        "id",
        "updater_id",
    }

    def __init__(
        self_,
        active: Union[bool, UnsetType] = unset,
        canceled: Union[int, none_type, UnsetType] = unset,
        creator_id: Union[int, UnsetType] = unset,
        disabled: Union[bool, UnsetType] = unset,
        downtime_type: Union[int, UnsetType] = unset,
        end: Union[int, none_type, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        monitor_id: Union[int, none_type, UnsetType] = unset,
        monitor_tags: Union[List[str], UnsetType] = unset,
        mute_first_recovery_notification: Union[bool, UnsetType] = unset,
        parent_id: Union[int, none_type, UnsetType] = unset,
        recurrence: Union[DowntimeRecurrence, none_type, UnsetType] = unset,
        scope: Union[List[str], UnsetType] = unset,
        start: Union[int, UnsetType] = unset,
        timezone: Union[str, UnsetType] = unset,
        updater_id: Union[int, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        The downtime object definition of the active child for the original parent recurring downtime. This
        field will only exist on recurring downtimes.

        :param active: If a scheduled downtime currently exists.
        :type active: bool, optional

        :param canceled: If a scheduled downtime is canceled.
        :type canceled: int, none_type, optional

        :param creator_id: User ID of the downtime creator.
        :type creator_id: int, optional

        :param disabled: If a downtime has been disabled.
        :type disabled: bool, optional

        :param downtime_type: ``0`` for a downtime applied on ``*`` or all,
            ``1`` when the downtime is only scoped to hosts,
            or ``2`` when the downtime is scoped to anything but hosts.
        :type downtime_type: int, optional

        :param end: POSIX timestamp to end the downtime. If not provided,
            the downtime is in effect indefinitely until you cancel it.
        :type end: int, none_type, optional

        :param id: The downtime ID.
        :type id: int, optional

        :param message: A message to include with notifications for this downtime.
            Email notifications can be sent to specific users by using the same ``@username`` notation as events.
        :type message: str, optional

        :param monitor_id: A single monitor to which the downtime applies.
            If not provided, the downtime applies to all monitors.
        :type monitor_id: int, none_type, optional

        :param monitor_tags: A comma-separated list of monitor tags. For example, tags that are applied directly to monitors,
            not tags that are used in monitor queries (which are filtered by the scope parameter), to which the downtime applies.
            The resulting downtime applies to monitors that match ALL provided monitor tags.
            For example, ``service:postgres`` **AND** ``team:frontend``.
        :type monitor_tags: [str], optional

        :param mute_first_recovery_notification: If the first recovery notification during a downtime should be muted.
        :type mute_first_recovery_notification: bool, optional

        :param parent_id: ID of the parent Downtime.
        :type parent_id: int, none_type, optional

        :param recurrence: An object defining the recurrence of the downtime.
        :type recurrence: DowntimeRecurrence, none_type, optional

        :param scope: The scope(s) to which the downtime applies. For example, ``host:app2``.
            Provide multiple scopes as a comma-separated list like ``env:dev,env:prod``.
            The resulting downtime applies to sources that matches ALL provided scopes ( ``env:dev`` **AND** ``env:prod`` ).
        :type scope: [str], optional

        :param start: POSIX timestamp to start the downtime.
            If not provided, the downtime starts the moment it is created.
        :type start: int, optional

        :param timezone: The timezone in which to display the downtime's start and end times in Datadog applications.
        :type timezone: str, optional

        :param updater_id: ID of the last user that updated the downtime.
        :type updater_id: int, none_type, optional
        """
        if active is not unset:
            kwargs["active"] = active
        if canceled is not unset:
            kwargs["canceled"] = canceled
        if creator_id is not unset:
            kwargs["creator_id"] = creator_id
        if disabled is not unset:
            kwargs["disabled"] = disabled
        if downtime_type is not unset:
            kwargs["downtime_type"] = downtime_type
        if end is not unset:
            kwargs["end"] = end
        if id is not unset:
            kwargs["id"] = id
        if message is not unset:
            kwargs["message"] = message
        if monitor_id is not unset:
            kwargs["monitor_id"] = monitor_id
        if monitor_tags is not unset:
            kwargs["monitor_tags"] = monitor_tags
        if mute_first_recovery_notification is not unset:
            kwargs["mute_first_recovery_notification"] = mute_first_recovery_notification
        if parent_id is not unset:
            kwargs["parent_id"] = parent_id
        if recurrence is not unset:
            kwargs["recurrence"] = recurrence
        if scope is not unset:
            kwargs["scope"] = scope
        if start is not unset:
            kwargs["start"] = start
        if timezone is not unset:
            kwargs["timezone"] = timezone
        if updater_id is not unset:
            kwargs["updater_id"] = updater_id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.creator import Creator
    from datadog_api_client.v1.model.service_level_objective_query import ServiceLevelObjectiveQuery
    from datadog_api_client.v1.model.slo_threshold import SLOThreshold
    from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe
    from datadog_api_client.v1.model.slo_type import SLOType


class SLOResponseData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.creator import Creator
        from datadog_api_client.v1.model.service_level_objective_query import ServiceLevelObjectiveQuery
        from datadog_api_client.v1.model.slo_threshold import SLOThreshold
        from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe
        from datadog_api_client.v1.model.slo_type import SLOType

        return {
            "configured_alert_ids": ([int],),
            "created_at": (int,),
            "creator": (Creator,),
            "description": (str, none_type),
            "groups": ([str],),
            "id": (str,),
            "modified_at": (int,),
            "monitor_ids": ([int],),
            "monitor_tags": ([str],),
            "name": (str,),
            "query": (ServiceLevelObjectiveQuery,),
            "tags": ([str],),
            "target_threshold": (float,),
            "thresholds": ([SLOThreshold],),
            "timeframe": (SLOTimeframe,),
            "type": (SLOType,),
            "warning_threshold": (float,),
        }

    attribute_map = {
        "configured_alert_ids": "configured_alert_ids",
        "created_at": "created_at",
        "creator": "creator",
        "description": "description",
        "groups": "groups",
        "id": "id",
        "modified_at": "modified_at",
        "monitor_ids": "monitor_ids",
        "monitor_tags": "monitor_tags",
        "name": "name",
        "query": "query",
        "tags": "tags",
        "target_threshold": "target_threshold",
        "thresholds": "thresholds",
        "timeframe": "timeframe",
        "type": "type",
        "warning_threshold": "warning_threshold",
    }
    read_only_vars = {
        "created_at",
        "creator",
        "id",
        "modified_at",
    }

    def __init__(
        self_,
        configured_alert_ids: Union[List[int], UnsetType] = unset,
        created_at: Union[int, UnsetType] = unset,
        creator: Union[Creator, UnsetType] = unset,
        description: Union[str, none_type, UnsetType] = unset,
        groups: Union[List[str], UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        modified_at: Union[int, UnsetType] = unset,
        monitor_ids: Union[List[int], UnsetType] = unset,
        monitor_tags: Union[List[str], UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        query: Union[ServiceLevelObjectiveQuery, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        target_threshold: Union[float, UnsetType] = unset,
        thresholds: Union[List[SLOThreshold], UnsetType] = unset,
        timeframe: Union[SLOTimeframe, UnsetType] = unset,
        type: Union[SLOType, UnsetType] = unset,
        warning_threshold: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        A service level objective object includes a service level indicator, thresholds
        for one or more timeframes, and metadata ( ``name`` , ``description`` , ``tags`` , etc.).

        :param configured_alert_ids: A list of SLO monitors IDs that reference this SLO. This field is returned only when ``with_configured_alert_ids`` parameter is true in query.
        :type configured_alert_ids: [int], optional

        :param created_at: Creation timestamp (UNIX time in seconds)

            Always included in service level objective responses.
        :type created_at: int, optional

        :param creator: Object describing the creator of the shared element.
        :type creator: Creator, optional

        :param description: A user-defined description of the service level objective.

            Always included in service level objective responses (but may be ``null`` ).
            Optional in create/update requests.
        :type description: str, none_type, optional

        :param groups: A list of (up to 20) monitor groups that narrow the scope of a monitor service level objective.

            Included in service level objective responses if it is not empty. Optional in
            create/update requests for monitor service level objectives, but may only be
            used when then length of the ``monitor_ids`` field is one.
        :type groups: [str], optional

        :param id: A unique identifier for the service level objective object.

            Always included in service level objective responses.
        :type id: str, optional

        :param modified_at: Modification timestamp (UNIX time in seconds)

            Always included in service level objective responses.
        :type modified_at: int, optional

        :param monitor_ids: A list of monitor ids that defines the scope of a monitor service level
            objective. **Required if type is monitor**.
        :type monitor_ids: [int], optional

        :param monitor_tags: The union of monitor tags for all monitors referenced by the ``monitor_ids``
            field.
            Always included in service level objective responses for monitor service level
            objectives (but may be empty). Ignored in create/update requests. Does not
            affect which monitors are included in the service level objective (that is
            determined entirely by the ``monitor_ids`` field).
        :type monitor_tags: [str], optional

        :param name: The name of the service level objective object.
        :type name: str, optional

        :param query: A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator
            to be used because this will sum up all request counts instead of averaging them, or taking the max or
            min of all of those requests.
        :type query: ServiceLevelObjectiveQuery, optional

        :param tags: A list of tags associated with this service level objective.
            Always included in service level objective responses (but may be empty).
            Optional in create/update requests.
        :type tags: [str], optional

        :param target_threshold: The target threshold such that when the service level indicator is above this
            threshold over the given timeframe, the objective is being met.
        :type target_threshold: float, optional

        :param thresholds: The thresholds (timeframes and associated targets) for this service level
            objective object.
        :type thresholds: [SLOThreshold], optional

        :param timeframe: The SLO time window options.
        :type timeframe: SLOTimeframe, optional

        :param type: The type of the service level objective.
        :type type: SLOType, optional

        :param warning_threshold: The optional warning threshold such that when the service level indicator is
            below this value for the given threshold, but above the target threshold, the
            objective appears in a "warning" state. This value must be greater than the target
            threshold.
        :type warning_threshold: float, optional
        """
        if configured_alert_ids is not unset:
            kwargs["configured_alert_ids"] = configured_alert_ids
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if creator is not unset:
            kwargs["creator"] = creator
        if description is not unset:
            kwargs["description"] = description
        if groups is not unset:
            kwargs["groups"] = groups
        if id is not unset:
            kwargs["id"] = id
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if monitor_ids is not unset:
            kwargs["monitor_ids"] = monitor_ids
        if monitor_tags is not unset:
            kwargs["monitor_tags"] = monitor_tags
        if name is not unset:
            kwargs["name"] = name
        if query is not unset:
            kwargs["query"] = query
        if tags is not unset:
            kwargs["tags"] = tags
        if target_threshold is not unset:
            kwargs["target_threshold"] = target_threshold
        if thresholds is not unset:
            kwargs["thresholds"] = thresholds
        if timeframe is not unset:
            kwargs["timeframe"] = timeframe
        if type is not unset:
            kwargs["type"] = type
        if warning_threshold is not unset:
            kwargs["warning_threshold"] = warning_threshold
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.topology_query import TopologyQuery
    from datadog_api_client.v1.model.topology_request_type import TopologyRequestType


class TopologyRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.topology_query import TopologyQuery
        from datadog_api_client.v1.model.topology_request_type import TopologyRequestType

        return {
            "query": (TopologyQuery,),
            "request_type": (TopologyRequestType,),
        }

    attribute_map = {
        "query": "query",
        "request_type": "request_type",
    }

    def __init__(
        self_,
        query: Union[TopologyQuery, UnsetType] = unset,
        request_type: Union[TopologyRequestType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Request that will return nodes and edges to be used by topology map.

        :param query: Query to service-based topology data sources like the service map or data streams.
        :type query: TopologyQuery, optional

        :param request_type: Widget request type.
        :type request_type: TopologyRequestType, optional
        """
        if query is not unset:
            kwargs["query"] = query
        if request_type is not unset:
            kwargs["request_type"] = request_type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.authn_mappings_response import AuthNMappingsResponse
from datadog_api_client.v2.model.authn_mappings_sort import AuthNMappingsSort
from datadog_api_client.v2.model.authn_mapping_response import AuthNMappingResponse
from datadog_api_client.v2.model.authn_mapping_create_request import AuthNMappingCreateRequest
from datadog_api_client.v2.model.authn_mapping_update_request import AuthNMappingUpdateRequest


class AuthNMappingsApi:
    """
    `AuthN Mappings API <https://docs.datadoghq.com/account_management/authn_mapping/?tab=example>`_
    is used to automatically map group of users to roles in Datadog using attributes
    sent from Identity Providers.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_authn_mapping_endpoint = _Endpoint(
            settings={
                "response_type": (AuthNMappingResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/authn_mappings",
                "operation_id": "create_authn_mapping",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AuthNMappingCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_authn_mapping_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/authn_mappings/{authn_mapping_id}",
                "operation_id": "delete_authn_mapping",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "authn_mapping_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "authn_mapping_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_authn_mapping_endpoint = _Endpoint(
            settings={
                "response_type": (AuthNMappingResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/authn_mappings/{authn_mapping_id}",
                "operation_id": "get_authn_mapping",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "authn_mapping_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "authn_mapping_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_authn_mappings_endpoint = _Endpoint(
            settings={
                "response_type": (AuthNMappingsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/authn_mappings",
                "operation_id": "list_authn_mappings",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "page_size": {
                    "openapi_types": (int,),
                    "attribute": "page[size]",
                    "location": "query",
                },
                "page_number": {
                    "openapi_types": (int,),
                    "attribute": "page[number]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (AuthNMappingsSort,),
                    "attribute": "sort",
                    "location": "query",
                },
                "filter": {
                    "openapi_types": (str,),
                    "attribute": "filter",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_authn_mapping_endpoint = _Endpoint(
            settings={
                "response_type": (AuthNMappingResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/authn_mappings/{authn_mapping_id}",
                "operation_id": "update_authn_mapping",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "authn_mapping_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "authn_mapping_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (AuthNMappingUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_authn_mapping(
        self,
        body: AuthNMappingCreateRequest,
    ) -> AuthNMappingResponse:
        """Create an AuthN Mapping.

        Create an AuthN Mapping.

        :type body: AuthNMappingCreateRequest
        :rtype: AuthNMappingResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_authn_mapping_endpoint.call_with_http_info(**kwargs)

    def delete_authn_mapping(
        self,
        authn_mapping_id: str,
    ) -> None:
        """Delete an AuthN Mapping.

        Delete an AuthN Mapping specified by AuthN Mapping UUID.

        :param authn_mapping_id: The UUID of the AuthN Mapping.
        :type authn_mapping_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["authn_mapping_id"] = authn_mapping_id

        return self._delete_authn_mapping_endpoint.call_with_http_info(**kwargs)

    def get_authn_mapping(
        self,
        authn_mapping_id: str,
    ) -> AuthNMappingResponse:
        """Get an AuthN Mapping by UUID.

        Get an AuthN Mapping specified by the AuthN Mapping UUID.

        :param authn_mapping_id: The UUID of the AuthN Mapping.
        :type authn_mapping_id: str
        :rtype: AuthNMappingResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["authn_mapping_id"] = authn_mapping_id

        return self._get_authn_mapping_endpoint.call_with_http_info(**kwargs)

    def list_authn_mappings(
        self,
        *,
        page_size: Union[int, UnsetType] = unset,
        page_number: Union[int, UnsetType] = unset,
        sort: Union[AuthNMappingsSort, UnsetType] = unset,
        filter: Union[str, UnsetType] = unset,
    ) -> AuthNMappingsResponse:
        """List all AuthN Mappings.

        List all AuthN Mappings in the org.

        :param page_size: Size for a given page. The maximum allowed value is 5000.
        :type page_size: int, optional
        :param page_number: Specific page number to return.
        :type page_number: int, optional
        :param sort: Sort AuthN Mappings depending on the given field.
        :type sort: AuthNMappingsSort, optional
        :param filter: Filter all mappings by the given string.
        :type filter: str, optional
        :rtype: AuthNMappingsResponse
        """
        kwargs: Dict[str, Any] = {}
        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_number is not unset:
            kwargs["page_number"] = page_number

        if sort is not unset:
            kwargs["sort"] = sort

        if filter is not unset:
            kwargs["filter"] = filter

        return self._list_authn_mappings_endpoint.call_with_http_info(**kwargs)

    def update_authn_mapping(
        self,
        authn_mapping_id: str,
        body: AuthNMappingUpdateRequest,
    ) -> AuthNMappingResponse:
        """Edit an AuthN Mapping.

        Edit an AuthN Mapping.

        :param authn_mapping_id: The UUID of the AuthN Mapping.
        :type authn_mapping_id: str
        :type body: AuthNMappingUpdateRequest
        :rtype: AuthNMappingResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["authn_mapping_id"] = authn_mapping_id

        kwargs["body"] = body

        return self._update_authn_mapping_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetPalette(ModelSimple):
    """
    Color palette to apply.

    :param value: Must be one of ["blue", "custom_bg", "custom_image", "custom_text", "gray_on_white", "grey", "green", "orange", "red", "red_on_white", "white_on_gray", "white_on_green", "green_on_white", "white_on_red", "white_on_yellow", "yellow_on_white", "black_on_light_yellow", "black_on_light_green", "black_on_light_red"].
    :type value: str
    """

    allowed_values = {
        "blue",
        "custom_bg",
        "custom_image",
        "custom_text",
        "gray_on_white",
        "grey",
        "green",
        "orange",
        "red",
        "red_on_white",
        "white_on_gray",
        "white_on_green",
        "green_on_white",
        "white_on_red",
        "white_on_yellow",
        "yellow_on_white",
        "black_on_light_yellow",
        "black_on_light_green",
        "black_on_light_red",
    }
    BLUE: ClassVar["WidgetPalette"]
    CUSTOM_BACKGROUND: ClassVar["WidgetPalette"]
    CUSTOM_IMAGE: ClassVar["WidgetPalette"]
    CUSTOM_TEXT: ClassVar["WidgetPalette"]
    GRAY_ON_WHITE: ClassVar["WidgetPalette"]
    GREY: ClassVar["WidgetPalette"]
    GREEN: ClassVar["WidgetPalette"]
    ORANGE: ClassVar["WidgetPalette"]
    RED: ClassVar["WidgetPalette"]
    RED_ON_WHITE: ClassVar["WidgetPalette"]
    WHITE_ON_GRAY: ClassVar["WidgetPalette"]
    WHITE_ON_GREEN: ClassVar["WidgetPalette"]
    GREEN_ON_WHITE: ClassVar["WidgetPalette"]
    WHITE_ON_RED: ClassVar["WidgetPalette"]
    WHITE_ON_YELLOW: ClassVar["WidgetPalette"]
    YELLOW_ON_WHITE: ClassVar["WidgetPalette"]
    BLACK_ON_LIGHT_YELLOW: ClassVar["WidgetPalette"]
    BLACK_ON_LIGHT_GREEN: ClassVar["WidgetPalette"]
    BLACK_ON_LIGHT_RED: ClassVar["WidgetPalette"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetPalette.BLUE = WidgetPalette("blue")
WidgetPalette.CUSTOM_BACKGROUND = WidgetPalette("custom_bg")
WidgetPalette.CUSTOM_IMAGE = WidgetPalette("custom_image")
WidgetPalette.CUSTOM_TEXT = WidgetPalette("custom_text")
WidgetPalette.GRAY_ON_WHITE = WidgetPalette("gray_on_white")
WidgetPalette.GREY = WidgetPalette("grey")
WidgetPalette.GREEN = WidgetPalette("green")
WidgetPalette.ORANGE = WidgetPalette("orange")
WidgetPalette.RED = WidgetPalette("red")
WidgetPalette.RED_ON_WHITE = WidgetPalette("red_on_white")
WidgetPalette.WHITE_ON_GRAY = WidgetPalette("white_on_gray")
WidgetPalette.WHITE_ON_GREEN = WidgetPalette("white_on_green")
WidgetPalette.GREEN_ON_WHITE = WidgetPalette("green_on_white")
WidgetPalette.WHITE_ON_RED = WidgetPalette("white_on_red")
WidgetPalette.WHITE_ON_YELLOW = WidgetPalette("white_on_yellow")
WidgetPalette.YELLOW_ON_WHITE = WidgetPalette("yellow_on_white")
WidgetPalette.BLACK_ON_LIGHT_YELLOW = WidgetPalette("black_on_light_yellow")
WidgetPalette.BLACK_ON_LIGHT_GREEN = WidgetPalette("black_on_light_green")
WidgetPalette.BLACK_ON_LIGHT_RED = WidgetPalette("black_on_light_red")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_basic_auth_sigv4_type import SyntheticsBasicAuthSigv4Type


class SyntheticsBasicAuthSigv4(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_basic_auth_sigv4_type import SyntheticsBasicAuthSigv4Type

        return {
            "access_key": (str,),
            "region": (str,),
            "secret_key": (str,),
            "service_name": (str,),
            "session_token": (str,),
            "type": (SyntheticsBasicAuthSigv4Type,),
        }

    attribute_map = {
        "access_key": "accessKey",
        "region": "region",
        "secret_key": "secretKey",
        "service_name": "serviceName",
        "session_token": "sessionToken",
        "type": "type",
    }

    def __init__(
        self_,
        access_key: str,
        secret_key: str,
        type: SyntheticsBasicAuthSigv4Type,
        region: Union[str, UnsetType] = unset,
        service_name: Union[str, UnsetType] = unset,
        session_token: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object to handle ``SIGV4`` authentication when performing the test.

        :param access_key: Access key for the ``SIGV4`` authentication.
        :type access_key: str

        :param region: Region for the ``SIGV4`` authentication.
        :type region: str, optional

        :param secret_key: Secret key for the ``SIGV4`` authentication.
        :type secret_key: str

        :param service_name: Service name for the ``SIGV4`` authentication.
        :type service_name: str, optional

        :param session_token: Session token for the ``SIGV4`` authentication.
        :type session_token: str, optional

        :param type: The type of authentication to use when performing the test.
        :type type: SyntheticsBasicAuthSigv4Type
        """
        if region is not unset:
            kwargs["region"] = region
        if service_name is not unset:
            kwargs["service_name"] = service_name
        if session_token is not unset:
            kwargs["session_token"] = session_token
        super().__init__(kwargs)

        self_.access_key = access_key
        self_.secret_key = secret_key
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.full_api_key_attributes import FullAPIKeyAttributes
    from datadog_api_client.v2.model.api_key_relationships import APIKeyRelationships
    from datadog_api_client.v2.model.api_keys_type import APIKeysType


class FullAPIKey(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.full_api_key_attributes import FullAPIKeyAttributes
        from datadog_api_client.v2.model.api_key_relationships import APIKeyRelationships
        from datadog_api_client.v2.model.api_keys_type import APIKeysType

        return {
            "attributes": (FullAPIKeyAttributes,),
            "id": (str,),
            "relationships": (APIKeyRelationships,),
            "type": (APIKeysType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: Union[FullAPIKeyAttributes, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        relationships: Union[APIKeyRelationships, UnsetType] = unset,
        type: Union[APIKeysType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Datadog API key.

        :param attributes: Attributes of a full API key.
        :type attributes: FullAPIKeyAttributes, optional

        :param id: ID of the API key.
        :type id: str, optional

        :param relationships: Resources related to the API key.
        :type relationships: APIKeyRelationships, optional

        :param type: API Keys resource type.
        :type type: APIKeysType, optional
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if id is not unset:
            kwargs["id"] = id
        if relationships is not unset:
            kwargs["relationships"] = relationships
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.api_key_create_attributes import APIKeyCreateAttributes
    from datadog_api_client.v2.model.api_keys_type import APIKeysType


class APIKeyCreateData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.api_key_create_attributes import APIKeyCreateAttributes
        from datadog_api_client.v2.model.api_keys_type import APIKeysType

        return {
            "attributes": (APIKeyCreateAttributes,),
            "type": (APIKeysType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "type": "type",
    }

    def __init__(self_, attributes: APIKeyCreateAttributes, type: APIKeysType, **kwargs):
        """
        Object used to create an API key.

        :param attributes: Attributes used to create an API Key.
        :type attributes: APIKeyCreateAttributes

        :param type: API Keys resource type.
        :type type: APIKeysType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_attribution_tag_names import UsageAttributionTagNames
    from datadog_api_client.v1.model.usage_attribution_values import UsageAttributionValues


class UsageAttributionBody(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_attribution_tag_names import UsageAttributionTagNames
        from datadog_api_client.v1.model.usage_attribution_values import UsageAttributionValues

        return {
            "month": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
            "tag_config_source": (str,),
            "tags": (UsageAttributionTagNames,),
            "updated_at": (str,),
            "values": (UsageAttributionValues,),
        }

    attribute_map = {
        "month": "month",
        "org_name": "org_name",
        "public_id": "public_id",
        "tag_config_source": "tag_config_source",
        "tags": "tags",
        "updated_at": "updated_at",
        "values": "values",
    }

    def __init__(
        self_,
        month: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        tag_config_source: Union[str, UnsetType] = unset,
        tags: Union[UsageAttributionTagNames, UnsetType] = unset,
        updated_at: Union[str, UnsetType] = unset,
        values: Union[UsageAttributionValues, UnsetType] = unset,
        **kwargs,
    ):
        """
        Usage Summary by tag for a given organization.

        :param month: Datetime in ISO-8601 format, UTC, precise to month: [YYYY-MM].
        :type month: datetime, optional

        :param org_name: The name of the organization.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param tag_config_source: The source of the usage attribution tag configuration and the selected tags in the format ``<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>``.
        :type tag_config_source: str, optional

        :param tags: Tag keys and values.

            A ``null`` value here means that the requested tag breakdown cannot be applied because it does not match the `tags
            configured for usage attribution <https://docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started>`_.
            In this scenario the API returns the total usage, not broken down by tags.
        :type tags: UsageAttributionTagNames, optional

        :param updated_at: Shows the the most recent hour in the current months for all organizations for which all usages were calculated.
        :type updated_at: str, optional

        :param values: Fields in Usage Summary by tag(s).
        :type values: UsageAttributionValues, optional
        """
        if month is not unset:
            kwargs["month"] = month
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if tag_config_source is not unset:
            kwargs["tag_config_source"] = tag_config_source
        if tags is not unset:
            kwargs["tags"] = tags
        if updated_at is not unset:
            kwargs["updated_at"] = updated_at
        if values is not unset:
            kwargs["values"] = values
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)


class MetricCustomAggregations(ModelSimple):
    """
    A list of queryable aggregation combinations for a count, rate, or gauge metric.
        By default, count and rate metrics require the (time: sum, space: sum) aggregation and
        Gauge metrics require the (time: avg, space: avg) aggregation.
        Additional time & space combinations are also available:

        * time: avg, space: avg
        * time: avg, space: max
        * time: avg, space: min
        * time: avg, space: sum
        * time: count, space: sum
        * time: max, space: max
        * time: min, space: min
        * time: sum, space: avg
        * time: sum, space: sum

        Can only be applied to metrics that have a ``metric_type`` of ``count`` , ``rate`` , or ``gauge``.


    :type value: [MetricCustomAggregation]
    """

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_custom_aggregation import MetricCustomAggregation

        return {
            "value": ([MetricCustomAggregation],),
        }



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType


class SyntheticsConfigVariable(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType

        return {
            "example": (str,),
            "id": (str,),
            "name": (str,),
            "pattern": (str,),
            "secure": (bool,),
            "type": (SyntheticsConfigVariableType,),
        }

    attribute_map = {
        "example": "example",
        "id": "id",
        "name": "name",
        "pattern": "pattern",
        "secure": "secure",
        "type": "type",
    }

    def __init__(
        self_,
        name: str,
        type: SyntheticsConfigVariableType,
        example: Union[str, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        pattern: Union[str, UnsetType] = unset,
        secure: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object defining a variable that can be used in your test configuration.

        :param example: Example for the variable.
        :type example: str, optional

        :param id: ID of the variable for global variables.
        :type id: str, optional

        :param name: Name of the variable.
        :type name: str

        :param pattern: Pattern of the variable.
        :type pattern: str, optional

        :param secure: Whether the value of this variable will be obfuscated in test results.
        :type secure: bool, optional

        :param type: Type of the configuration variable.
        :type type: SyntheticsConfigVariableType
        """
        if example is not unset:
            kwargs["example"] = example
        if id is not unset:
            kwargs["id"] = id
        if pattern is not unset:
            kwargs["pattern"] = pattern
        if secure is not unset:
            kwargs["secure"] = secure
        super().__init__(kwargs)

        self_.name = name
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_device import SyntheticsDevice


class SyntheticsBrowserTestResultShortResult(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_device import SyntheticsDevice

        return {
            "device": (SyntheticsDevice,),
            "duration": (float,),
            "error_count": (int,),
            "step_count_completed": (int,),
            "step_count_total": (int,),
        }

    attribute_map = {
        "device": "device",
        "duration": "duration",
        "error_count": "errorCount",
        "step_count_completed": "stepCountCompleted",
        "step_count_total": "stepCountTotal",
    }

    def __init__(
        self_,
        device: Union[SyntheticsDevice, UnsetType] = unset,
        duration: Union[float, UnsetType] = unset,
        error_count: Union[int, UnsetType] = unset,
        step_count_completed: Union[int, UnsetType] = unset,
        step_count_total: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object with the result of the last browser test run.

        :param device: Object describing the device used to perform the Synthetic test.
        :type device: SyntheticsDevice, optional

        :param duration: Length in milliseconds of the browser test run.
        :type duration: float, optional

        :param error_count: Amount of errors collected for a single browser test run.
        :type error_count: int, optional

        :param step_count_completed: Amount of browser test steps completed before failing.
        :type step_count_completed: int, optional

        :param step_count_total: Total amount of browser test steps.
        :type step_count_total: int, optional
        """
        if device is not unset:
            kwargs["device"] = device
        if duration is not unset:
            kwargs["duration"] = duration
        if error_count is not unset:
            kwargs["error_count"] = error_count
        if step_count_completed is not unset:
            kwargs["step_count_completed"] = step_count_completed
        if step_count_total is not unset:
            kwargs["step_count_total"] = step_count_total
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_query_compute import LogsQueryCompute
    from datadog_api_client.v1.model.log_query_definition_group_by import LogQueryDefinitionGroupBy
    from datadog_api_client.v1.model.log_query_definition_search import LogQueryDefinitionSearch


class LogQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_query_compute import LogsQueryCompute
        from datadog_api_client.v1.model.log_query_definition_group_by import LogQueryDefinitionGroupBy
        from datadog_api_client.v1.model.log_query_definition_search import LogQueryDefinitionSearch

        return {
            "compute": (LogsQueryCompute,),
            "group_by": ([LogQueryDefinitionGroupBy],),
            "index": (str,),
            "multi_compute": ([LogsQueryCompute],),
            "search": (LogQueryDefinitionSearch,),
        }

    attribute_map = {
        "compute": "compute",
        "group_by": "group_by",
        "index": "index",
        "multi_compute": "multi_compute",
        "search": "search",
    }

    def __init__(
        self_,
        compute: Union[LogsQueryCompute, UnsetType] = unset,
        group_by: Union[List[LogQueryDefinitionGroupBy], UnsetType] = unset,
        index: Union[str, UnsetType] = unset,
        multi_compute: Union[List[LogsQueryCompute], UnsetType] = unset,
        search: Union[LogQueryDefinitionSearch, UnsetType] = unset,
        **kwargs,
    ):
        """
        The log query.

        :param compute: Define computation for a log query.
        :type compute: LogsQueryCompute, optional

        :param group_by: List of tag prefixes to group by in the case of a cluster check.
        :type group_by: [LogQueryDefinitionGroupBy], optional

        :param index: A coma separated-list of index names. Use "*" query all indexes at once. `Multiple Indexes <https://docs.datadoghq.com/logs/indexes/#multiple-indexes>`_
        :type index: str, optional

        :param multi_compute: This field is mutually exclusive with ``compute``.
        :type multi_compute: [LogsQueryCompute], optional

        :param search: The query being made on the logs.
        :type search: LogQueryDefinitionSearch, optional
        """
        if compute is not unset:
            kwargs["compute"] = compute
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if index is not unset:
            kwargs["index"] = index
        if multi_compute is not unset:
            kwargs["multi_compute"] = multi_compute
        if search is not unset:
            kwargs["search"] = search
        super().__init__(kwargs)
